@@ -701,7 +701,9 @@ static MaskedPixmap *image_from_desktop_file(const char *path)
 		 * Remove them.
 		 */
 		extension = strrchr(icon, '.');
-		if (extension && strcmp(extension, ".png") == 0)
+		if (extension && (strcmp(extension, ".png") == 0 
+						|| strcmp(extension, ".xpm") == 0
+						|| strcmp(extension, ".svg") == 0))
 		{
 			*extension = '\0';
 		}
@@ -709,8 +711,7 @@ static MaskedPixmap *image_from_desktop_file(const char *path)
 		/* SVG reader is very noisy, so redirect stderr to stdout */
 		tmp_fd = dup(2);
 		dup2(1, 2);
-		pixbuf = gtk_icon_theme_load_icon(icon_theme, icon, HUGE_WIDTH,
-							0, NULL);
+		pixbuf = theme_load_icon(icon, HUGE_WIDTH, 0, NULL);
 		dup2(tmp_fd, 2);
 		close(tmp_fd);
 
@@ -1073,7 +1074,7 @@ static int s2n(const unsigned char *dat, int off, int len, char format)
 static GdkPixbuf *extract_tiff_thumbnail(const gchar *path)
 {
     FILE *in;
-    char header[256];
+    unsigned char header[256];
     int i, n;
     int length;
     unsigned char *data;
@@ -1089,8 +1090,8 @@ static GdkPixbuf *extract_tiff_thumbnail(const gchar *path)
 
     /* Check for Exif format */
     n=fread(header, 1, 12, in);
-    if(n!=12 || strncmp(header, "\377\330\377\341", 4)!=0 ||
-       strncmp(header+6, "Exif", 4)!=0) {
+    if(n!=12 || strncmp((char *) header, "\377\330\377\341", 4)!=0 ||
+       strncmp((char *)header+6, "Exif", 4)!=0) {
         fclose(in);
         return NULL;
     }
